% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/forecasts.R
\name{aemo_pasa}
\alias{aemo_pasa}
\title{Projected Assessment of System Adequacy (PASA)}
\usage{
aemo_pasa(
  horizon = c("short", "medium"),
  region = NULL,
  start = NULL,
  end = NULL
)
}
\arguments{
\item{horizon}{One of \code{"short"} (default) or \code{"medium"}.}

\item{region}{Optional NEM region code.}

\item{start, end}{Optional window of run-times. Defaults to
the last 24 hours.}
}
\value{
An \code{aemo_tbl}.
}
\description{
Returns short-term (\code{STPASA}, 1-7 day) or medium-term
(\code{MTPASA}, 2-year) system adequacy projections.
}
\examples{
\donttest{
op <- options(aemo.cache_dir = tempdir())
try({
  p <- aemo_pasa(horizon = "short", region = "NSW1")
})
options(op)
}
}
\seealso{
Other forecast: 
\code{\link{aemo_predispatch}()}
}
\concept{forecast}
