% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reference.R
\name{aemo_interconnectors}
\alias{aemo_interconnectors}
\title{NEM interconnectors}
\usage{
aemo_interconnectors()
}
\value{
An \code{aemo_tbl} with columns \code{interconnector_id},
\code{from_region}, \code{to_region}, \code{name}, \code{energised}.
}
\description{
Returns a static table of the seven NEM interconnectors. The
seventh entry is Project EnergyConnect (PEC), whose Stage 1
was energised on 30 April 2025 with full ~800 MW capability
expected mid-2026.
}
\examples{
aemo_interconnectors()
}
\seealso{
Other reference: 
\code{\link{aemo_dlf}()},
\code{\link{aemo_mlf}()},
\code{\link{aemo_participants}()},
\code{\link{aemo_price_caps}()},
\code{\link{aemo_regions}()},
\code{\link{aemo_settlement}()},
\code{\link{aemo_snapshot}()},
\code{\link{aemo_units}()}
}
\concept{reference}
