% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cache.R
\name{aemo_cache_info}
\alias{aemo_cache_info}
\title{Inspect the local aemo cache}
\usage{
aemo_cache_info()
}
\value{
A list with \code{dir}, \code{n_files}, \code{size_bytes}, \code{size_human}, \code{files}.
}
\description{
Inspect the local aemo cache
}
\examples{
\donttest{
op <- options(aemo.cache_dir = tempdir())
aemo_cache_info()
options(op)
}
}
\seealso{
Other configuration: 
\code{\link{aemo_clear_cache}()},
\code{\link{aemo_throttle}()}
}
\concept{configuration}
