% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/interconnector.R
\name{aemo_interconnector}
\alias{aemo_interconnector}
\title{NEM interconnector flows}
\usage{
aemo_interconnector(flow = NULL, start, end, intervention = FALSE)
}
\arguments{
\item{flow}{Optional character vector of interconnector IDs.}

\item{start, end}{Window.}

\item{intervention}{Logical. Default \code{FALSE}.}
}
\value{
An \code{aemo_tbl}.
}
\description{
Returns MW flows, losses, and limits for one or more NEM
interconnectors from \code{DISPATCHINTERCONNECTORRES}.
}
\details{
AEMO's \code{METEREDMWFLOW} is positive when power flows from
\code{REGIONFROM} to \code{REGIONTO}. For per-interconnector direction
conventions see \code{\link[=aemo_interconnectors]{aemo_interconnectors()}}.
}
\examples{
\donttest{
op <- options(aemo.cache_dir = tempdir())
try({
  now <- Sys.time()
  i <- aemo_interconnector(flow = "V-SA",
                            start = now - 3600, end = now)
  head(i)
})
options(op)
}
}
\seealso{
Other dispatch: 
\code{\link{aemo_bids}()},
\code{\link{aemo_constraints}()},
\code{\link{aemo_dispatch_units}()},
\code{\link{aemo_fcas_enablement}()},
\code{\link{aemo_gencon}()},
\code{\link{aemo_market_notices}()},
\code{\link{aemo_outages}()},
\code{\link{aemo_rooftop_pv}()},
\code{\link{aemo_spd_constraints}()}
}
\concept{dispatch}
