% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/aemo-package.R
\docType{package}
\name{aemo-package}
\alias{aemo}
\alias{aemo-package}
\title{aemo: Australian Energy Market Operator Data}
\description{
Tidy R access to AEMO's public data: wholesale electricity
prices, demand, dispatch, interconnector flows, rooftop PV,
bids, predispatch and PASA forecasts, FCAS markets, and gas
markets across the NEM.
}
\section{Main function families}{

\itemize{
\item \code{\link[=aemo_price]{aemo_price()}}, \code{\link[=aemo_demand]{aemo_demand()}}: workhorse price and demand.
\item \code{\link[=aemo_dispatch_units]{aemo_dispatch_units()}}, \code{\link[=aemo_interconnector]{aemo_interconnector()}},
\code{\link[=aemo_rooftop_pv]{aemo_rooftop_pv()}}: dispatch and flow.
\item \code{\link[=aemo_bids]{aemo_bids()}}, \code{\link[=aemo_predispatch]{aemo_predispatch()}}, \code{\link[=aemo_pasa]{aemo_pasa()}}: bids
and forecasts.
\item \code{\link[=aemo_fcas]{aemo_fcas()}}, \code{\link[=aemo_gas]{aemo_gas()}}: ancillary services and gas.
\item \code{\link[=aemo_units]{aemo_units()}}, \code{\link[=aemo_regions]{aemo_regions()}}, \code{\link[=aemo_interconnectors]{aemo_interconnectors()}}:
reference data.
\item \code{\link[=aemo_nemweb_ls]{aemo_nemweb_ls()}}, \code{\link[=aemo_nemweb_download]{aemo_nemweb_download()}}: low-level
escape hatches for arbitrary NEMweb paths.
\item \code{\link[=aemo_cache_info]{aemo_cache_info()}}, \code{\link[=aemo_clear_cache]{aemo_clear_cache()}}, \code{\link[=aemo_throttle]{aemo_throttle()}}:
configuration.
}
}

\section{Data source}{

Data is published by AEMO at \url{http://nemweb.com.au} under the
AEMO Copyright Permissions Notice
\url{https://www.aemo.com.au/privacy-and-legal-notices/copyright-permissions}.
}

\seealso{
Useful links:
\itemize{
  \item \url{https://charlescoverdale.github.io/aemo/}
  \item \url{https://github.com/charlescoverdale/aemo}
  \item Report bugs at \url{https://github.com/charlescoverdale/aemo/issues}
}

}
\author{
\strong{Maintainer}: Charles Coverdale \email{charlesfcoverdale@gmail.com}

}
\concept{AEMO}
\concept{NEM}
\concept{electricity market}
\concept{wholesale electricity}
\keyword{internal}
